.. cosmospectra documentation master file, created by
   sphinx-quickstart on Wed Jan  8 07:50:14 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

CosmoSpectra's documentation!
========================================
CosmoSpectra package is meant for Fourier analysis of cosmological simulations.

.. toctree::
   :maxdepth: 2

Modules
=======

.. toctree::
   :maxdepth: 2

   power_spectrum_response

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
